@@ -55,13 +55,15 @@
 #include "config.h"
 #include "drawit.h"
 
-#ifdef __WIN32__
+#ifdef _WIN32
 	#include <windows.h>
 #endif
 
 #define BEGINDEF extern
 #include "begin.h"
 
+using namespace std;
+
 extern string GLE_TOP_DIR;
 extern string GLE_BIN_DIR;
 extern ConfigCollection g_Config;
@@ -142,10 +144,10 @@ void init_config(ConfigCollection* collection) {
 	section = new ConfigSection("tools");
 	/* LaTeX */
 	strarg = section->addStringOption("latex", GLE_TOOL_LATEX_CMD);
-#ifdef __WIN32__
+#ifdef _WIN32
 	strarg->setDefault("latex.exe");
 #endif
-#ifdef __UNIX__
+#if defined(__unix__) || defined(__APPLE__)
 	strarg->setDefault("latex");
 #endif
 #ifdef __OS2__
@@ -155,7 +157,7 @@ void init_config(ConfigCollection* collection) {
 
 	/* PdfLaTeX */
 	strarg = section->addStringOption("pdflatex", GLE_TOOL_PDFTEX_CMD);
-#ifdef __WIN32__
+#ifdef _WIN32
 	strarg->setDefault("pdflatex.exe");
 #else
 	strarg->setDefault("pdflatex");
@@ -164,10 +166,10 @@ void init_config(ConfigCollection* collection) {
 
 	/* DVIPS */
 	strarg = section->addStringOption("dvips", GLE_TOOL_DVIPS_CMD);
-#ifdef __WIN32__
+#ifdef _WIN32
 	strarg->setDefault("dvips.exe");
 #endif
-#ifdef __UNIX__
+#if defined(__unix__) || defined(__APPLE__)
 	strarg->setDefault("dvips");
 #endif
 #ifdef __OS2__
@@ -176,7 +178,7 @@ void init_config(ConfigCollection* collection) {
 	section->addStringOption("dvips_options", GLE_TOOL_DVIPS_OPTIONS);
 	/* GhostScript Program */
 	strarg = section->addStringOption("ghostscript", GLE_TOOL_GHOSTSCRIPT_CMD);
-#ifdef __WIN32__
+#ifdef _WIN32
 	#define ENVIRONMENT32
 	#if _WIN32 || _WIN64
 		// Visual Studio builds with cl.exe
@@ -201,10 +203,10 @@ void init_config(ConfigCollection* collection) {
 		strarg->setDefault("gswin64c.exe");
 	#endif
 #endif
-#ifdef __MACOS__
+#ifdef __APPLE__
 	strarg->setDefault("gs,glegs;$EXELOC/glegs");
 #endif
-#if defined(__UNIX__) && !defined(__MACOS__)
+#if defined(__unix__) && !defined(__APPLE__)
 	strarg->setDefault("gs");
 #endif
 #ifdef __OS2__
@@ -215,7 +217,7 @@ void init_config(ConfigCollection* collection) {
 	collection->addSection(section, GLE_CONFIG_TOOLS);
 	/* GhostScript Library */
 	strarg = section->addStringOption("libgs", GLE_TOOL_GHOSTSCRIPT_LIB);
-#ifdef __WIN32__
+#ifdef _WIN32
 	#define ENVIRONMENT32
 	#if _WIN32 || _WIN64
 		// Visual Studio builds with cl.exe
@@ -240,10 +242,10 @@ void init_config(ConfigCollection* collection) {
 		strarg->setDefault("gsdll64.dll");
 	#endif
 #endif
-#ifdef __MACOS__
+#ifdef __APPLE__
 	strarg->setDefault("/Library/Frameworks/Ghostscript.framework,Ghostscript.framework");
 #endif
-#if defined(__UNIX__) && !defined(__MACOS__)
+#if defined(__unix__) && !defined(__APPLE__)
 	strarg->setDefault("/usr/lib/libgs.so");
 #endif
 	strarg = section->addStringOption("editor", GLE_TOOL_TEXT_EDITOR);
@@ -444,7 +446,7 @@ void find_deps(const string& loc, GLEInterface* iface) {
 	vector<string*> result;
 	string gle_paths = ";";
 	ConfigCollection* collection = iface->getConfig()->getRCFile();
-#ifdef __WIN32__
+#ifdef _WIN32
 	GLEFindEntry* findGLE = new GLEFindEntry(&gle_paths);
 	findGLE->addToFind("gle.exe");
 	findGLE->addToFind("gle_ps.exe");
@@ -500,11 +502,11 @@ void find_deps(const string& loc, GLEInterface* iface) {
 			}
 		}
 	}
-	#ifdef __UNIX__
+	#if defined(__unix__) || defined(__APPLE__)
 		// Find programs in search path on Unix
 		GLEFindPrograms(tofind, &progress);
 	#endif
-	#ifdef __MACOS__
+	#ifdef __APPLE__
 		// Search for frameworks on Mac
 		GLEFindFiles(string("/Library/Frameworks"), tofind, &progress);
 		string home = GetHomeDir();
@@ -516,7 +518,7 @@ void find_deps(const string& loc, GLEInterface* iface) {
 	for (unsigned int i = 0; i < tofind.size(); i++) {
 		tofind[i]->updateResult(true);
 	}
-	#ifdef __UNIX__
+	#if defined(__unix__) || defined(__APPLE__)
 		// Search for libraries in typical directories and in LD_LIBRARY_PATH
 		string gslibloc = GLEFindLibrary("libgs", &progress);
 		if (gslibloc != "") {
@@ -668,7 +670,7 @@ bool do_load_config(const char* appname, char **argv, CmdLineObj& cmdline, Confi
 				StripPathComponents(&GLE_TOP_DIR, 2);
 			#endif
 		} else {
-			// The user will see as error messege: "$GLE_TOP/some_file" not found.
+			// The user will see as error message: "$GLE_TOP/some_file" not found.
 			GLE_TOP_DIR = "$GLE_TOP";
 		}
 	} else {
@@ -705,7 +707,7 @@ bool do_load_config(const char* appname, char **argv, CmdLineObj& cmdline, Confi
 
 void do_find_deps_sub(GLEInterface* iface, const string& loc) {
 	string myloc = loc;
-#ifdef __WIN32__
+#ifdef _WIN32
 	if (myloc.length() == 0) {
 		GLEGetEnv("ProgramFiles", myloc);
 	}
