@@ -50,6 +50,8 @@
 #include <cairo-pdf.h>
 #include <cairo-svg.h>
 
+using namespace std;
+
 /************************************************************************************
  * Fonts in Cairo:
  *
@@ -967,7 +969,7 @@ int GLECairoDeviceEPS::getDeviceType() {
 	return GLE_DEVICE_CAIRO_EPS;
 }
 
-#ifdef __WIN32__
+#ifdef _WIN32
 
 #include <cairo-win32.h>
 
