@@ -38,6 +38,7 @@
 
 #include <fstream>
 #include <set>
+#include <string>
 
 #include "all.h"
 #include "cutils.h"
@@ -62,6 +63,8 @@
 #include "run.h"
 #include "gle-poppler.h"
 
+using namespace std;
+
 // TODO make these available through the interface
 extern CmdLineObj g_CmdLine;
 extern ConfigCollection g_Config;
@@ -566,7 +569,7 @@ bool GLEInterface::isDeviceSupported(int device) {
 		case GLE_DEVICE_SVG:
         case GLE_DEVICE_CAIRO_SVG:
 			return true;
-#ifdef __WIN32__
+#ifdef _WIN32
         case GLE_DEVICE_EMF:
 			return true;
 #endif
@@ -611,7 +614,7 @@ bool GLEInterface::hasCmdLineOptionString(const char* name) {
 
 string GLEInterface::getGhostScriptLocation() {
 	ConfigSection* tools = g_Config.getSection(GLE_CONFIG_TOOLS);
-#ifdef __WIN32__
+#ifdef _WIN32
 	string name = "gsdll32.dll";
 	#if _WIN64
 		// VS builds
@@ -650,10 +653,10 @@ string GLEInterface::getToolLocation(const char* name) {
 
 string GLEInterface::getUserConfigLocation() {
 	string location;
-	#if defined(__UNIX__) || defined (__OS2__)
+	#if defined(__unix__) || defined(__APPLE__) || defined (__OS2__)
 		GLEGetEnv("HOME", location);
 	#endif
-	#ifdef __WIN32__	
+	#ifdef _WIN32	
 		GLEGetEnv("APPDATA", location);
 		if (location != "") {
 			AddDirSep(location);
