@@ -43,6 +43,8 @@
 #include "gprint.h"
 #include "numberformat.h"
 
+using namespace std;
+
 /*
 	dec, hex [upper|lower], bin
 	01
@@ -54,7 +56,7 @@
 
 	round 3
 	round number to 3 significant digits
-	pad with zeros if number too large (don't use exponential represenations)
+	pad with zeros if number too large (don't use exponential representations)
 
 	nozeros
 
