@@ -228,33 +228,40 @@ struct op_key op_marker[] = {
 		{ "CROSS", 	typ_switch, 	1, 2 },
 		{ "FCIRCLE", 	typ_switch, 	1, 3 },
 		{ "FSQUARE", 	typ_switch, 	1, 4 },
-		{ "FTRIANGLE", 	typ_switch, 	1, 5 },
-		{ "FDIAMOND", 	typ_switch, 	1, 6 },
-		{ "CIRCLE", 	typ_switch, 	1, 7 },
-		{ "SQUARE", 	typ_switch, 	1, 8 },
-		{ "TRIANGLE", 	typ_switch, 	1, 9 },
-		{ "DIAMOND", 	typ_switch, 	1, 10 },
-		{ "PLUS", 	typ_switch, 	1, 11 },
-		{ "CLUB", 	typ_switch, 	1, 12 },
-		{ "HEART", 	typ_switch, 	1, 13 },
-		{ "DIAMOND", 	typ_switch, 	1, 14 },
-		{ "SPADE", 	typ_switch, 	1, 15 },
-		{ "STAR", 	typ_switch, 	1, 16 },
-		{ "SNAKE", 	typ_switch, 	1, 17 },
-		{ "DAG", 	typ_switch, 	1, 18 },
-		{ "DDAG", 	typ_switch, 	1, 19 },
-		{ "ASTERIX", 	typ_switch, 	1, 20 },
-		{ "ASTERISK", 	typ_switch, 	1, 20 },
-		{ "OPLUS", 	typ_switch, 	1, 21 },
-		{ "OMINUS", 	typ_switch, 	1, 22 },
-		{ "OTIMES", 	typ_switch, 	1, 23 },
-		{ "ODOT", 	typ_switch, 	1, 24 },
-		{ "TRIANGLEZ", 	typ_switch, 	1, 25 },
-		{ "DIAMONDZ", 	typ_switch, 	1, 26 },
-		{ "WCIRCLE", 	typ_switch, 	1, 27 },
-		{ "WTRIANGLE", 	typ_switch, 	1, 28 },
-		{ "WSQUARE", 	typ_switch, 	1, 29 },
-		{ "WDIAMOND", 	typ_switch, 	1, 30 },
+		{ "FTRIANGLE",  typ_switch, 	1, 5 },
+		{ "FTRIANGLED", typ_switch, 	1, 6 },
+		{ "FDIAMOND", 	typ_switch, 	1, 7 },
+		{ "FSTARR", 	typ_switch, 	1, 8 },
+		{ "CIRCLE", 	typ_switch, 	1, 9 },
+		{ "SQUARE", 	typ_switch, 	1, 10 },
+		{ "TRIANGLE", 	typ_switch, 	1, 11 },
+		{ "TRIANGLED",  typ_switch, 	1, 12 },
+		{ "DIAMOND", 	typ_switch, 	1, 13 },
+		{ "STARR", 	typ_switch, 	1, 14 },
+		{ "PLUS", 	typ_switch, 	1, 15 },
+		{ "PCROSS", 	typ_switch, 	1, 16 },
+		{ "CLUB", 	typ_switch, 	1, 17 },
+		{ "HEART", 	typ_switch, 	1, 18 },
+		{ "DIAMOND", 	typ_switch, 	1, 19 },
+		{ "SPADE", 	typ_switch, 	1, 20 },
+		{ "STAR", 	typ_switch, 	1, 21 },
+		{ "SNAKE", 	typ_switch, 	1, 22 },
+		{ "DAG", 	typ_switch, 	1, 23 },
+		{ "DDAG", 	typ_switch, 	1, 24 },
+		{ "ASTERIX", 	typ_switch, 	1, 25 },
+		{ "ASTERISK", 	typ_switch, 	1, 25 },
+		{ "OPLUS", 	typ_switch, 	1, 26 },
+		{ "OMINUS", 	typ_switch, 	1, 27 },
+		{ "OTIMES", 	typ_switch, 	1, 28 },
+		{ "ODOT", 	typ_switch, 	1, 29 },
+		{ "TRIANGLEZ",  typ_switch, 	1, 30 },
+		{ "DIAMONDZ", 	typ_switch, 	1, 31 },
+		{ "WCIRCLE", 	typ_switch, 	1, 32 },
+		{ "WTRIANGLE",  typ_switch, 	1, 33 },
+		{ "WTRIANGLED", typ_switch, 	1, 34 },
+		{ "WSQUARE", 	typ_switch, 	1, 35 },
+		{ "WDIAMOND", 	typ_switch, 	1, 36 },
+		{ "WSTARR", 	typ_switch, 	1, 37 },
 		{ "END", 	typ_end, 	1, 1  } };
 
 struct op_key op_begin_path[] = {
