@@ -60,10 +60,12 @@ void name_get2(char *n,double *x1,double *y1,double *x2,double *y2);
 #define GRAPHDEF extern
 #include "graph.h"
 
+using namespace std;
+
 extern OPKEY op_begin;
 extern GLESubMap g_Subroutines;
 
-extern int **gpcode;   /* gpcode is a pointer to an array of poiter to int */
+extern int **gpcode;   /* gpcode is a pointer to an array of pointer to int */
 extern int *gplen;     /* gpcode is a pointer to an array of int */
 
 string get_b_name(int jj) {
@@ -508,6 +510,7 @@ GLERun::GLERun(GLEScript* script, GLEFileLocation* outfile, GLEPcodeIndexed* pco
 	allowBeforeSize(GLE_KW_UNTIL);
 	allowBeforeSize(GLE_KW_WHILE);
 	allowBeforeSize(GLE_KW_END);
+	allowBeforeSize(GLE_KW_SWAP);
 }
 
 GLERun::~GLERun() {
@@ -1665,6 +1668,27 @@ void GLERun::do_pcode(GLESourceLine &sline, int *srclin, int *pcode, int plen, i
 			readlong(jj); /* block type */
 			getBlockTypes()->getBlock(jj)->executeLine(sline);
 			break;
+		  case GLE_KW_SWAP:
+		  	readlong(jj);
+		  	readlong(jj2);
+		  	t = var_get_type(jj);
+		  	j = var_get_type(jj2);
+		  	if(t != j){
+		  		g_throw_parser_error("SWAP ERROR variables must be same type");
+		  	}
+		  	if(t == 2){
+		  		std::string s1,s2;
+				var_getstr(jj,s1);
+		  		var_getstr(jj2,s2);
+		  		var_setstr(jj,(char*)s2.c_str());
+				var_setstr(jj2,(char*)s1.c_str());
+		  	}else{
+		  		var_get(jj,&x);
+		  		var_get(jj2,&y);
+		  		var_set(jj,y);
+				var_set(jj2,x);
+		  	}
+			break;
 		  default :
 		  	byte_code_error(PCODE_UNKNOWN_COMMAND);
 		}
